@@ -1,6 +1,6 @@
 use v6;
 
-unit class Path::Finder:ver<0.2.0>;
+unit class Path::Finder:ver<0.2.1>;
 
 use IO::Glob;
 
@@ -420,7 +420,8 @@ our sub finder(Path::Finder :$base = Path::Finder, *%options --> Path::Finder) i
 	my Entry @entries;
 	for %options.kv -> $name, $value {
 		my $method = $base.^lookup($name);
-		die "Finder key $name invalid" if not $method.defined or $method !~~ Constraint;
+		die "Finder key $name doesn't exist" if not $method.defined;
+		die "Finder key $name isn't a contraint" if $method !~~ Constraint;
 		my $capture = $value ~~ Capture ?? $value !! do given $method.signature.count - 1 {
 			when 1 {
 				\($value);
@@ -428,6 +429,9 @@ our sub finder(Path::Finder :$base = Path::Finder, *%options --> Path::Finder) i
 			when Inf {
 				\(|@($value).map: -> $entry { $entry ~~ Hash|Pair ?? finder(|%($entry)) !! $entry });
 			}
+			default {
+				die "Finder key $name doesn't have a usable signature";
+			}
 		}
 		@entries.push: Entry.new(:$name, :$method, :$capture);
 	}
@@ -448,16 +452,15 @@ our sub find(*@dirs, *%options --> Seq:D) is export(:DEFAULT :find) {
 
  use Path::Finder;
 
- my $finder = Path::Finder; # match anything
- $finder = $rule.file.size(* > 10_000);    # add/chain rules
+ my $finder = Path::Finder.file.skip-vcs.ext(/pm6?/).size(* > 10_000);
 
  # iterator interface
- for $finder.in(@dirs) -> $file {
+ for $finder.in('.') -> $file {
    ...
  }
 
  # functional interface
- for find(@dirs, :file, :size(* > 10_000)) -> $file {
+ for find(:file, :skip-vcs, :ext(/pm6?/), :size(* > 10_000)) -> $file {
    ...
  }
 
@@ -468,8 +471,7 @@ user-defined set of rules. The object-oriented API is based heavily on
 perl5's C<Path::Iterator::Rule>. A C<Path::Finder> object is a
 collection of rules (match criteria) with methods to add additional criteria.
 Options that control directory traversal are given as arguments to the method
-that generates an iterator. There is also a functional interface that is often
-simpler in use, even if it allows for slightly less control.
+that generates an iterator.
 
 Here is a summary of features for comparison to other file finding modules:
 
@@ -491,8 +493,12 @@ Here is a summary of features for comparison to other file finding modules:
 
 =head1 USAGE
 
+There are two interfaces: an object oriented one, and a functional one.
+
 Path::Finder objects are immutable. All methods except C<in> return a new object combining the existing rules with the additional rules provided.
 
+When using the C<find> function, all methods described below (except C<in>) are allowed as named arguments. This is usually the easiest way to use Path::Finder, even if it allows for slightly less control. There is also a C<finder> function that returns a Path::Finder object.
+
 =head2 Matching and iteration
 
 =head3 C<in>
@@ -520,7 +526,7 @@ current directory is used (C<".">). Valid options include:
 
 =item C<sorted> - Whether entries in a directory are sorted before processing. Default is C<True>.
 
-=item C<keep-going> - Whether or not the search should continue when an error is encountered (typically and unreadable directory). Defaults to C<True>.
+=item C<keep-going> - Whether or not the search should continue when an error is encountered (typically an unreadable directory). Defaults to C<True>.
 
 =item C<quiet> - Whether printing non-fatal errors to C<$*ERR> is repressed. Defaults to C<False>.
 
@@ -977,4 +983,7 @@ Consider:
 Rule C<$f3> above will be much faster, not only because it stacks
 the file tests, but because it requires to only check a single rule.
 
+When using the C<find> function, C<Path::Finder> will try to sort the arguments
+automatically in such a way that cheap checks and skipping checks are done first.
+
 =end pod
